summaryrefslogtreecommitdiffstats
path: root/lib/Controller/ItemController.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Controller/ItemController.php')
-rw-r--r--lib/Controller/ItemController.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/Controller/ItemController.php b/lib/Controller/ItemController.php
index ec56a9e33..a437bf3ff 100644
--- a/lib/Controller/ItemController.php
+++ b/lib/Controller/ItemController.php
@@ -330,16 +330,16 @@ class ItemController extends Controller
/**
* @NoAdminRequired
*
* @param int $itemId Item to share
* @param string $shareWithId User to share with
*/
- public function share($itemId, $shareWithId)
+ public function share($itemId, $shareRecipientId)
{
try {
$this->shareService->shareItemWithUser(
$this->getUserId(),
$itemId,
- $shareWithId
+ $shareRecipientId
);
} catch (ServiceNotFoundException $ex) {
return $this->error($ex, Http::STATUS_NOT_FOUND);
@@ -330,16 +330,16 @@ class ItemController extends Controller
* @NoAdminRequired
*
- * @param int $itemId Item to share
- * @param string $shareWithId User to share with
+ * @param int $itemId Item to share
+ * @param string $shareRecipientId User to share the item with
*/